@@ -402,16 +402,16 @@ int main(void) {
         }
         printf("=> Test22: OK\n\n");
         
-        printf("=> Test23: Str_ntos\n");
+        printf("=> Test23: Str_ton\n");
         {
                 char str[43];
                 long l1 = 42, l2 = 0, l3 = -42, l4 = LONG_MAX, l5 = LONG_MIN;
-                assert(Str_isByteEqual("42", Str_ntos(42, (char[43]){0})));
-                assert(Str_isByteEqual("42", Str_ntos(l1, str)));
-                assert(Str_isByteEqual("0", Str_ntos(l2, str)));
-                assert(Str_isByteEqual("-42", Str_ntos(l3, str)));
-                assert(l4 == Str_parseLLong(Str_ntos(l4, str)));
-                assert(l5 == Str_parseLLong(Str_ntos(l5, str)));
+                assert(Str_isByteEqual("42", Str_ton(42, (char[43]){0})));
+                assert(Str_isByteEqual("42", Str_ton(l1, str)));
+                assert(Str_isByteEqual("0", Str_ton(l2, str)));
+                assert(Str_isByteEqual("-42", Str_ton(l3, str)));
+                assert(l4 == Str_parseLLong(Str_ton(l4, str)));
+                assert(l5 == Str_parseLLong(Str_ton(l5, str)));
         }
         printf("=> Test23: OK\n\n");
         
